@@ -12,14 +12,15 @@ import pandas as pd
 import numpy as np
 from .log import Log
 from .pack import Pack
+from .dictionaries.units import correct_units as correct_units_
 
 try:
     import simpandas as spd
 except ModuleNotFoundError:
     pass
 
-__version__ = '0.1.5'
-__release__ = 20230209
+__version__ = '0.1.7'
+__release__ = 20230221
 
 
 class DLISIOError(Exception):
@@ -30,9 +31,11 @@ class DLISIOError(Exception):
         self.message = 'ERROR: reading DLIS file ' + message
 
 
-def dlis2frame(path: str, use_simpandas=False, raise_error=True):
+def dlis2frame(path: str, use_simpandas=False, raise_error=True, correct_units=True):
     if not os.path.isfile(path):
         raise FileNotFoundError("The provided path can't be found:\n" + str(path))
+    if type(path) is str:
+        path = path.replace('\\', '/')
 
     try:
         physical_file = dlis.load(path)
@@ -72,6 +75,8 @@ def dlis2frame(path: str, use_simpandas=False, raise_error=True):
         meta.set_index('name', inplace=True)
         for frame in logical_file.frames:
             frame_units = {channel.name: channel.units for channel in frame.channels}
+            if correct_units:
+                frame_units = correct_units_(frame_units)
             try:
                 curves_df = pd.DataFrame(frame.curves()).set_index(frame.index)
             except ValueError:
@@ -85,12 +90,27 @@ def dlis2frame(path: str, use_simpandas=False, raise_error=True):
             frames[(l_count, frame.name)] = (curves_df, meta, pd.Series(frame_units, name='frame_units'), well_name)
     physical_file.close()
 
-    frames = {name: Log(data=data[0] if not use_simpandas else spd.SimDataFrame(data=data[0], units=data[2], name=data[3], meta=data[1], source=path),
-                        header=data[1],
-                        units=data[2],
-                        source=path,
-                        well=data[3]) for name, data in frames.items()}
     if len(frames) == 1:
+        frames = {name: Log(
+            data=data[0] if not use_simpandas else spd.SimDataFrame(data=data[0], units=data[2], name=data[3],
+                                                                    meta=data[1],
+                                                                    source=str(path)),
+            header=data[1],
+            units=data[2],
+            source=str(path),
+            well=data[3]) for name, data in frames.items()}
         return frames[list(frames.keys())[0]]
     else:
+        frames = {name: Log(
+            data=data[0] if not use_simpandas else spd.SimDataFrame(data=data[0], units=data[2], name=data[3],
+                                                                    meta=data[1],
+                                                                    source='logical file ' + str(name[0]) +
+                                                                           ', frame ' + str(name[1]) +
+                                                                           ' in: ' + path),
+            header=data[1],
+            units=data[2],
+            source='logical file ' + str(name[0]) +
+                   ', frame ' + str(name[1]) +
+                   ' in: ' + path,
+            well=data[3]) for name, data in frames.items()}
         return Pack(frames)
